==> php83-nextcloud-29.0.7.tgz: share/nextcloud/apps/circles/l10n/de_DE.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Teams",
    "You created the team {circle}" : "Sie haben das Team {circle} erstellt",
    "{author} created the team {circle}" : "{author} hat das Team {circle} erstellt",
    "You deleted {circle}" : "Sie haben {circle} gelöscht",
    "{author} deleted {circle}" : "{author} hat {circle} gelöscht",
    "You made {member} join {circle}" : "Sie haben {member} {circle} beitreten lassen.",
    "{author} made {member} join {circle}" : "{author} hat {member} {circle} beitreten lassen",
    "You added team {member} as member to {circle}" : "Sie haben das Team {member} als Mitglied zu {circle} hinzugefügt",
    "{author} added team {member} as member to {circle}" : "{author} hat das Team {member} als Mitglied zu {circle} hinzugefügt",
    "You made {member} leave {circle}" : "Sie haben {member} aus {circle} entfernt",
    "{author} made {member} leave {circle}" : "{author} hat {member} aus {circle} entfernt",
    "You removed {member} from {circle}" : "Sie haben {member} aus {circle} entfernt",
    "{author} removed {member} from {circle}" : "{author} hat {member} aus {circle} entfernt",
    "You joined {circle}" : "Sie sind dem {circle} beigetreten",
    "{member} joined {circle}" : "{member} ist {circle} beigetreten",
    "You accepted the invitation to join {circle}" : "Sie haben die Einladung angenommen {circle} beizutreten",
    "{member} accepted the invitation to join {circle}" : "{member} hat die Einladung angenommen {circle} beizutreten",
    "You added {member} as member to {circle}" : "Sie haben {member} dem Kreis {circle} hinzugefügt",
    "You have been added as member to {circle} by {author}" : "Sie wurden von {author} als Mitglied zu {circle} hinzugefügt",
    "{member} has been added as member to {circle} by {author}" : "{member} wurde von {author} als Mitglied zu {circle} hinzugefügt",
    "You added {external} to {circle}" : "Sie haben {external} zu {circle} hinzugefügt",
    "{external} has been added to {circle} by {author}" : "{external} wurde von {author} zu {circle} hinzugefügt",
    "You accepted {member}'s request to join {circle}" : "Sie haben {member}s Anfrage angenommen {circle} beizutreten",
    "Your request to join {circle} has been accepted by {author}" : "Ihre Anfrage {circle} beizutreten wurde von {author} angenommen",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}s Anfrage {circle} beizutreten wurde von {author} angenommen",
    "You left {circle}" : "Sie haben {circle} verlassen",
    "{member} left {circle}" : "{member} hat {circle} verlassen",
    "You declined the invitation to join {circle}" : "Sie haben die Einladung {circle} beizutreten abgelehnt",
    "{member} declined an invitation to join {circle}" : "{member} hat es abgelehnt {circle} beizutreten",
    "You cancelled your request to join {circle}" : "Sie haben Ihre Anfrage {circle} beizutreten zurückgezogen",
    "{member} cancelled a request to join {circle}" : "{member} hat seine Anfrage {circle} beizutreten abgebrochen",
    "You have been removed from {circle} by {author}" : "Sie wurden von {author} aus {circle} entfernt",
    "{member} has been removed from {circle} by {author}" : "{member} wurde von {author} aus {circle} entfernt",
    "You removed {external} from {circle}" : "Sie haben {external} von {circle} entfernt",
    "{external} has been removed from {circle} by {author}" : "{external} wurde von {author} von {circle} entfernt",
    "You cancelled {member}'s invitation to join {circle}" : "Sie haben die Einladung an {member} {circle} beizutreten zurückgezogen",
    "Your invitation to join {circle} has been cancelled by {author}" : "Ihre Einladung {circle} beizutreten wurde von {author} zurückgezogen",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} hat die Einladung an {member} {circle} beizutreten zurückgezogen",
    "You dismissed {member}'s request to join {circle}" : "Sie haben {member}s Anfrage {circle} beizutreten abgelehnt",
    "Your request to join {circle} has been dismissed by {author}" : "Ihre Anfrage {circle} beizutreten wurde von {author} abgelehnt",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}s Anfrage {circle} beizutreten wurde von {author} abgelehnt",
    "You invited {member} to join {circle}" : "Sie haben {member} eingeladen {circle} beizutreten",
    "You have been invited to join {circle} by {author}" : "Sie wurden von {author} eingeladen {circle} beizutreten",
    "{member} has been invited to join {circle} by {author}" : "{member} wurde von {author} eingeladen {circle} beizutreten",
    "You changed {member}'s level in {circle} to %1$s" : "Sie haben {member}s Rang in {circle} zu %1$s geändert",
    "{author} changed your level in {circle} to %1$s" : "{author} hat Ihren Rang in {circle} zu %1$s geändert",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} hat {member}s Rang in {circle} zu %1$s geändert",
    "You sent a request to join {circle}" : "Sie haben eine Anfrage gestellt in {circle} aufgenommen zu werden",
    "{member} sent a request to join {circle}" : "{member} hat eine Anfrage gestellt in {circle} aufgenommen zu werden",
    "You are the new owner of {circle}" : "Sie sind der neue Eigentümer von {circle}",
    "{member} is the new owner of {circle}" : "{member} ist der neue Eigentümer von {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Bei Ereignissen in einem <strong>Team</strong>, in dem Sie Mitglied sind",
    "Any important event in a <strong>team</strong> you are moderating" : "Jeder wichtige Termin in einem <strong>Team</strong>, das Sie moderieren",
    "On global events happening in any <strong>team</strong>" : "Bei globalen Ereignissen, in einem beliebigen <strong>Team</strong>",
    "Shared to Circles" : "Geteilt mit Kreisen",
    "Single" : "Einzeln",
    "Personal" : "Persönlich",
    "System" : "System",
    "Visible" : "Sichtbar",
    "Open" : "Offen",
    "Invite" : "Einladen",
    "Join request" : "Beitrittsanfrage",
    "Friends" : "Freunde",
    "Password protected" : "Passwortgeschützt",
    "No Owner" : "Kein Besitzer",
    "Hidden" : "Versteckt",
    "Backend" : "Backend",
    "Local" : "Lokal",
    "Root" : "Root",
    "Team invite" : "Teameinladung",
    "Federated" : "Federated",
    "Mount point" : "Einhängepunkt",
    "Nextcloud Account" : "Nextcloud-Konto",
    "Nextcloud Group" : "Nextcloud-Gruppe",
    "Email address" : "E-Mail-Adresse",
    "Contact" : "Kontakt",
    "Circle" : "Kreis",
    "Nextcloud App" : "Nextcloud-App",
    "Member" : "Mitglied",
    "Moderator" : "Moderator",
    "Admin" : "Administration",
    "Owner" : "Eigentümer",
    "%s shared »%s« with you." : "%s hat »%s« mit Ihnen geteilt.",
    "%s shared »%s« with \"%s\"." : "%s hat »%s« mit \"%s\" geteilt.",
    "%s on %s" : "%s in %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat »%2$s« mit Ihnen geteilt.\nSie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s hat »%2$s« mit Ihnen geteilt. Sie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.",
    "Password to access »%1$s« shared to you by %2$s" : "Das Passwort zum Zugriff auf %1$s wurde Ihnen von %2$s mitgeteilt.",
    "Password to access »%s«" : "Passwort für den Zugriff auf »%s«",
    "It is protected with the following password:" : "Dies ist mit folgendem Passwort geschützt:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Zum Öffnen auf die untenstehende Schaltfläche klicken.",
    "Open »%s«" : "Öffne »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s hat mehrere Dateien mit Ihnen geteilt.\nSie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s hat mehrere Dateien mit Ihnen geteilt. Sie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben. ",
    "Password to access files shared to you by %1$s" : "Passwort für den Zugriff auf Dateien, die von %1$s mit Ihnen geteilt wurden",
    "Password to access files" : "Passwort für den Dateizugriff",
    "%s shared multiple files with \"%s\"." : "%s hat mehrere Dateien mit \"%s\" geteilt.",
    "%s shared multiple files with you." : "%s hat mehrere Dateien mit Ihnen geteilt.",
    "Boot up" : "Hochfahren",
    "Nextcloud Initialization" : "Nextcloud-Initialisierung",
    "Circles App Initialization" : "Initialisierung der Kreise-App",
    "Fresh installation status" : "Aktueller Initialisierungsstatus",
    "Building Local Database" : "Lokale Datenbank wird erstellt",
    "Testing Basic Circle Creation" : "Testen der grundlegenden Kreiserstellung",
    "Adding local users and moderators" : "Lokale Benutzer und Moderatoren werden hinzugefügt",
    "Show all teams" : "Alle Teams anzeigen",
    "Create a new team" : "Ein neues Team erstellen",
    "Files" : "Dateien",
    "This feature is not available for personal circles" : "Diese Funktion steht für persönliche Kreise nicht zur Verfügung",
    "The team is not federated" : "Das Team ist nicht federiert",
    "You cannot join this team" : "Du kannst diesem Team nicht beitreten",
    "This member is not a moderator" : "Dieses Mitglied ist kein Moderator",
    "Insufficient privileges" : "Unzureichende Berechtigungen ",
    "This member does not exist" : "Dieses Mitglied existiert nicht",
    "This member is the owner of the team" : "Dieses Mitglied ist der Besitzer des Teams",
    "Level cannot be changed for this type of member" : "Berechtigungsstufe kann für diesen Mitgliedstyp nicht geändert werden",
    "You are already a member of this circle" : "Sie sind bereits Mitglied dieses Kreises",
    "You have been blocked from this circle" : "Sie wurden für diesen Kreis blockiert",
    "The account is already a member of this circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
    "The account has already been invited into this circle" : "Dieses Konto wurde bereits zu diesem Kreis eingeladen.",
    "%s (Team owned by %s)" : "%s (Team im Besitz von %s)",
    "You are now a member of the Circle \"%2$s\"" : "Sie sind jetzt ein Mitglied des Kreises \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Sie wurden von %1$s zum Kreis \"%2$s\" eingeladen",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s hat eine Mitgliedschaftsanfrage für den Kreis \"%2$s\" gesendet",
    "Accept" : "Annehmen",
    "Refuse" : "Ablehnen",
    "Leave the circle" : "Diesen Kreis verlassen",
    "%s" : "%s",
    "Personal team" : "Persönliches Team",
    "%s owned by %s" : "%s gehört %s",
    "You have no permission to create a new team" : "Sie haben nicht die Berechtigung, ein neues Team zu erstellen",
    "%s shared a file with \"%s\"." : "%s hat eine Datei mit \"%s\" geteilt.",
    "%s shared a file with you." : "%s hat eine Datei mit Ihnen geteilt.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat einigen Inhalt mit Ihnen geteilt.\nSie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s hat einigen Inhalt mit Ihnen geteilt. Sie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.",
    "Password to access content shared with you by %1$s" : "Passwort für den Zugriff auf den Inhalt, der von %1$s mit Ihnen geteilt wurde.",
    "Password to access content" : "Passwort für den Zugriff auf den Inhalt",
    "This item is already shared with this team" : "Dieses Element wurde bereits mit diesem Team geteilt",
    "Bring cloud-users closer together." : "Bringen Sie Cloudnutzer näher zueinander.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Mittels Teams können Personen ihre eigenen Gruppen mit Personen/Kollegen/Freunden erstellen.\nDiese Personengruppen können dann von jeder anderen App zum Teilen verwendet werden.",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden ",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "Circles" : "Kreise",
    "Circles' files" : "Dateien des Kreises",
    "Select circles to filter by" : "Kreise wählen, um hiernach zu filtern",
    "No circles found" : "Keine Kreise gefunden",
    "Please select circles to filter by" : "Bitte wählen Sie Kreise, um hiernach zu filtern",
    "No files found for the selected circles" : "Keine Dateien für die ausgewählten Kreise gefunden",
    "You created the circle {circle}" : "Sie haben den Kreis {circle} erstellt",
    "{author} created the circle {circle}" : "{author} hat den Kreis {circle} erstellt",
    "You added circle {member} as member to {circle}" : "Sie haben den Kreis {member} als Mitglied zu {circle} hinzugefügt",
    "{author} added circle {member} has been added as member to {circle}" : "{author} hat den Kreis {member} als Mitglied zu {circle} hinzugefügt",
    "You removed {member} leave {circle}" : "Sie haben {member} aus {circle} entfernt",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Bei Ereignissen in einem <strong>Kreis</strong> , in dem Du Mitglied bist",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Irgend ein wichtiger Termin in einem <strong>Kreis</strong> den Sie moderieren",
    "On global events happening in any <strong>Circle</strong>" : "Bei globalen Ereignissen in irgendeinem <strong>Kreis</strong> ",
    "Join Request" : "Beitrittsanfrage",
    "Password Protected" : "Passwortgeschützt",
    "Circle Invite" : "Einladung zu Kreis",
    "Email Address" : "E-Mail-Adresse",
    "Circle not found" : "Kreis nicht gefunden",
    "Circle not found " : "Kreis nicht gefunden",
    "This account is already a member of the circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
    "Federated link not found" : "Federated-Verknüpfung nicht gefunden",
    "The circle is not federated" : "Der Kreis ist nicht federated",
    "You cannot join this circle" : "Sie können diesem Kreis nicht beitreten",
    "This member is the owner of the circle" : "Dieses Mitglied ist der Besitzer des Kreises",
    "%s (Circle owned by %s)" : "%s (Kreis im Besitz von %s)",
    "Personal Circle" : "Persönlicher Kreis",
    "You need a specify a type of circle" : "Sie benötigen einen bestimmten Kreis-Typ",
    "A circle with that name exists" : "Ein Kreis mit diesem Namen existiert bereits",
    "This member is not the owner of the circle" : "Dieses Mitglied ist nicht der Besitzer des Kreises",
    "This member is not an admin of the circle" : "Dieses Mitglied ist kein Administrator dieses Kreises ",
    "Group contains too many members" : "Gruppe hat zu viele Mitglieder",
    "This group does not exist" : "Diese Gruppe existiert nicht",
    "This group is already linked to the circle" : "Diese Gruppe ist bereits mit diesem Kreis verknüpft",
    "You cannot edit level in a personal circle" : "Sie können das Level in einem persönlichen Kreis nicht bearbeiten",
    "Group cannot be set as owner of a circle" : "Eine Gruppe kann nicht Besitzer eines Kreises sein",
    "now" : "jetzt",
    "This account does not exist" : "Dieses Konto existiert nicht",
    "Email format is not valid" : "Das E-Mail-Format ist ungültig",
    "This contact is not available" : "Dieser Kontakt ist nicht verfügbar",
    "You have no permission to create a new circle" : "Sie haben nicht die Berechtigung einen neuen Kreis zu erstellen",
    "This item is already shared with this circle" : "Dieses Element wird bereits mit diesem Kreis geteilt",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Mit Kreisen können Benutzer ihre eigenen Gruppen von Benutzern/Kollegen/Freunden erstellen.\nDiese Benutzergruppen (oder \"Kreise\") können dann von jeder anderen App zum Zweck der gemeinsamen Nutzung verwendet werden.",
    "Teams' files" : "Team-Dateien",
    "Select team to filter by" : "Team auswählen, nach dem gefiltert werden soll",
    "No teams found" : "Keine Teams gefunden",
    "Please select teams to filter by" : "Bitte wählen Sie Teams, nach denen gefiltert werden soll",
    "No files found for the selected teams" : "Keine Dateien für die ausgewählten Teams gefunden",
    "{author} added team {member} has been added as member to {circle}" : "{author} hat das Team {member} als Mitglied zu {circle} hinzugefügt"
},
"nplurals=2; plural=(n != 1);");

==> php83-nextcloud-30.0.11.tgz: share/nextcloud/apps/circles/l10n/de_DE.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Teams",
    "You created the team {circle}" : "Sie haben das Team {circle} erstellt",
    "{author} created the team {circle}" : "{author} hat das Team {circle} erstellt",
    "You deleted {circle}" : "Sie haben {circle} gelöscht",
    "{author} deleted {circle}" : "{author} hat {circle} gelöscht",
    "You made {member} join {circle}" : "Sie haben {member} {circle} beitreten lassen.",
    "{author} made {member} join {circle}" : "{author} hat {member} {circle} beitreten lassen",
    "You added team {member} as member to {circle}" : "Sie haben das Team {member} als Mitglied zu {circle} hinzugefügt",
    "{author} added team {member} as member to {circle}" : "{author} hat das Team {member} als Mitglied zu {circle} hinzugefügt",
    "You made {member} leave {circle}" : "Sie haben {member} aus {circle} entfernt",
    "{author} made {member} leave {circle}" : "{author} hat {member} aus {circle} entfernt",
    "You removed {member} from {circle}" : "Sie haben {member} aus {circle} entfernt",
    "{author} removed {member} from {circle}" : "{author} hat {member} aus {circle} entfernt",
    "You joined {circle}" : "Sie sind dem {circle} beigetreten",
    "{member} joined {circle}" : "{member} ist {circle} beigetreten",
    "You accepted the invitation to join {circle}" : "Sie haben die Einladung angenommen {circle} beizutreten",
    "{member} accepted the invitation to join {circle}" : "{member} hat die Einladung angenommen {circle} beizutreten",
    "You added {member} as member to {circle}" : "Sie haben {member} dem Kreis {circle} hinzugefügt",
    "You have been added as member to {circle} by {author}" : "Sie wurden von {author} als Mitglied zu {circle} hinzugefügt",
    "{member} has been added as member to {circle} by {author}" : "{member} wurde von {author} als Mitglied zu {circle} hinzugefügt",
    "You added {external} to {circle}" : "Sie haben {external} zu {circle} hinzugefügt",
    "{external} has been added to {circle} by {author}" : "{external} wurde von {author} zu {circle} hinzugefügt",
    "You accepted {member}'s request to join {circle}" : "Sie haben {member}s Anfrage angenommen {circle} beizutreten",
    "Your request to join {circle} has been accepted by {author}" : "Ihre Anfrage {circle} beizutreten wurde von {author} angenommen",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}s Anfrage {circle} beizutreten wurde von {author} angenommen",
    "You left {circle}" : "Sie haben {circle} verlassen",
    "{member} left {circle}" : "{member} hat {circle} verlassen",
    "You declined the invitation to join {circle}" : "Sie haben die Einladung {circle} beizutreten abgelehnt",
    "{member} declined an invitation to join {circle}" : "{member} hat es abgelehnt {circle} beizutreten",
    "You cancelled your request to join {circle}" : "Sie haben Ihre Anfrage {circle} beizutreten zurückgezogen",
    "{member} cancelled a request to join {circle}" : "{member} hat seine Anfrage {circle} beizutreten abgebrochen",
    "You have been removed from {circle} by {author}" : "Sie wurden von {author} aus {circle} entfernt",
    "{member} has been removed from {circle} by {author}" : "{member} wurde von {author} aus {circle} entfernt",
    "You removed {external} from {circle}" : "Sie haben {external} von {circle} entfernt",
    "{external} has been removed from {circle} by {author}" : "{external} wurde von {author} von {circle} entfernt",
    "You cancelled {member}'s invitation to join {circle}" : "Sie haben die Einladung an {member} {circle} beizutreten zurückgezogen",
    "Your invitation to join {circle} has been cancelled by {author}" : "Ihre Einladung {circle} beizutreten wurde von {author} zurückgezogen",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} hat die Einladung an {member} {circle} beizutreten zurückgezogen",
    "You dismissed {member}'s request to join {circle}" : "Sie haben {member}s Anfrage {circle} beizutreten abgelehnt",
    "Your request to join {circle} has been dismissed by {author}" : "Ihre Anfrage {circle} beizutreten wurde von {author} abgelehnt",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}s Anfrage {circle} beizutreten wurde von {author} abgelehnt",
    "You invited {member} to join {circle}" : "Sie haben {member} eingeladen {circle} beizutreten",
    "You have been invited to join {circle} by {author}" : "Sie wurden von {author} eingeladen {circle} beizutreten",
    "{member} has been invited to join {circle} by {author}" : "{member} wurde von {author} eingeladen {circle} beizutreten",
    "You changed {member}'s level in {circle} to %1$s" : "Sie haben {member}s Rang in {circle} zu %1$s geändert",
    "{author} changed your level in {circle} to %1$s" : "{author} hat Ihren Rang in {circle} zu %1$s geändert",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} hat {member}s Rang in {circle} zu %1$s geändert",
    "You sent a request to join {circle}" : "Sie haben eine Anfrage gestellt in {circle} aufgenommen zu werden",
    "{member} sent a request to join {circle}" : "{member} hat eine Anfrage gestellt in {circle} aufgenommen zu werden",
    "You are the new owner of {circle}" : "Sie sind der neue Eigentümer von {circle}",
    "{member} is the new owner of {circle}" : "{member} ist der neue Eigentümer von {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Bei Ereignissen in einem <strong>Team</strong>, in dem Sie Mitglied sind",
    "Any important event in a <strong>team</strong> you are moderating" : "Jeder wichtige Termin in einem <strong>Team</strong>, das Sie moderieren",
    "On global events happening in any <strong>team</strong>" : "Bei globalen Ereignissen, in einem beliebigen <strong>Team</strong>",
    "Single" : "Einzeln",
    "Personal" : "Persönlich",
    "System" : "System",
    "Visible" : "Sichtbar",
    "Open" : "Offen",
    "Invite" : "Einladen",
    "Join request" : "Beitrittsanfrage",
    "Friends" : "Freunde",
    "Password protected" : "Passwortgeschützt",
    "No Owner" : "Kein Besitzer",
    "Hidden" : "Versteckt",
    "Backend" : "Backend",
    "Local" : "Lokal",
    "Root" : "Root",
    "Team invite" : "Teameinladung",
    "Federated" : "Federated",
    "Mount point" : "Einhängepunkt",
    "Nextcloud Account" : "Nextcloud-Konto",
    "Nextcloud Group" : "Nextcloud-Gruppe",
    "Email address" : "E-Mail-Adresse",
    "Contact" : "Kontakt",
    "Circle" : "Kreis",
    "Nextcloud App" : "Nextcloud-App",
    "Member" : "Mitglied",
    "Moderator" : "Moderator",
    "Admin" : "Administration",
    "Owner" : "Eigentümer",
    "%s shared »%s« with you." : "%s hat »%s« mit Ihnen geteilt.",
    "%s shared »%s« with \"%s\"." : "%s hat »%s« mit \"%s\" geteilt.",
    "%s on %s" : "%s in %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat »%2$s« mit Ihnen geteilt.\nSie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s hat »%2$s« mit Ihnen geteilt. Sie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.",
    "Password to access »%1$s« shared to you by %2$s" : "Das Passwort zum Zugriff auf %1$s wurde Ihnen von %2$s mitgeteilt.",
    "Password to access »%s«" : "Passwort für den Zugriff auf »%s«",
    "It is protected with the following password:" : "Dies ist mit folgendem Passwort geschützt:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Zum Öffnen auf die untenstehende Schaltfläche klicken.",
    "Open »%s«" : "Öffne »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s hat mehrere Dateien mit Ihnen geteilt.\nSie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s hat mehrere Dateien mit Ihnen geteilt. Sie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben. ",
    "Password to access files shared to you by %1$s" : "Passwort für den Zugriff auf Dateien, die von %1$s mit Ihnen geteilt wurden",
    "Password to access files" : "Passwort für den Dateizugriff",
    "%s shared multiple files with \"%s\"." : "%s hat mehrere Dateien mit \"%s\" geteilt.",
    "%s shared multiple files with you." : "%s hat mehrere Dateien mit Ihnen geteilt.",
    "Boot up" : "Hochfahren",
    "Nextcloud Initialization" : "Nextcloud-Initialisierung",
    "Circles App Initialization" : "Initialisierung der Kreise-App",
    "Fresh installation status" : "Aktueller Initialisierungsstatus",
    "Building Local Database" : "Lokale Datenbank wird erstellt",
    "Testing Basic Circle Creation" : "Testen der grundlegenden Kreiserstellung",
    "Adding local users and moderators" : "Lokale Benutzer und Moderatoren werden hinzugefügt",
    "Show all teams" : "Alle Teams anzeigen",
    "Create a new team" : "Ein neues Team erstellen",
    "Files" : "Dateien",
    "This feature is not available for personal circles" : "Diese Funktion steht für persönliche Kreise nicht zur Verfügung",
    "The team is not federated" : "Das Team ist nicht federiert",
    "You cannot join this team" : "Du kannst diesem Team nicht beitreten",
    "This member is not a moderator" : "Dieses Mitglied ist kein Moderator",
    "Insufficient privileges" : "Unzureichende Berechtigungen ",
    "This member does not exist" : "Dieses Mitglied existiert nicht",
    "This member is the owner of the team" : "Dieses Mitglied ist der Besitzer des Teams",
    "Level cannot be changed for this type of member" : "Berechtigungsstufe kann für diesen Mitgliedstyp nicht geändert werden",
    "You are already a member of this circle" : "Sie sind bereits Mitglied dieses Kreises",
    "You have been blocked from this circle" : "Sie wurden für diesen Kreis blockiert",
    "The account is already a member of this circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
    "The account has already been invited into this circle" : "Dieses Konto wurde bereits zu diesem Kreis eingeladen.",
    "%s (Team owned by %s)" : "%s (Team im Besitz von %s)",
    "You are now a member of the Team \"%2$s\"" : "Sie sind jetzt Mitglied des Teams \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Sie wurden von %1$s zum Team \"%2$s\" eingeladen",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s hat eine Mitgliedschaftsanfrage für das Team \"%2$s\" gesendet",
    "Accept" : "Annehmen",
    "Refuse" : "Ablehnen",
    "Leave the team" : "Das Team verlassen",
    "%s" : "%s",
    "Personal team" : "Persönliches Team",
    "%s owned by %s" : "%s gehört %s",
    "You have no permission to create a new team" : "Sie haben nicht die Berechtigung, ein neues Team zu erstellen",
    "%s shared a file with \"%s\"." : "%s hat eine Datei mit \"%s\" geteilt.",
    "%s shared a file with you." : "%s hat eine Datei mit Ihnen geteilt.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat einigen Inhalt mit Ihnen geteilt.\nSie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s hat einigen Inhalt mit Ihnen geteilt. Sie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.",
    "Password to access content shared with you by %1$s" : "Passwort für den Zugriff auf den Inhalt, der von %1$s mit Ihnen geteilt wurde.",
    "Password to access content" : "Passwort für den Zugriff auf den Inhalt",
    "This item is already shared with this team" : "Dieses Element wurde bereits mit diesem Team geteilt",
    "Bring cloud-users closer together." : "Bringen Sie Cloudnutzer näher zueinander.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Mittels Teams können Personen ihre eigenen Gruppen mit Personen/Kollegen/Freunden erstellen.\nDiese Personengruppen können dann von jeder anderen App zum Teilen verwendet werden.",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden ",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "Teams' files" : "Team-Dateien",
    "Select team to filter by" : "Team auswählen, nach dem gefiltert werden soll",
    "No teams found" : "Keine Teams gefunden",
    "Please select teams to filter by" : "Bitte wählen Sie Teams, nach denen gefiltert werden soll",
    "No files found for the selected teams" : "Keine Dateien für die ausgewählten Teams gefunden",
    "{author} added team {member} has been added as member to {circle}" : "{author} hat das Team {member} als Mitglied zu {circle} hinzugefügt",
    "Shared to Circles" : "Geteilt mit Kreisen",
    "You are now a member of the Circle \"%2$s\"" : "Sie sind jetzt ein Mitglied des Kreises \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Sie wurden von %1$s zum Kreis \"%2$s\" eingeladen",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s hat eine Mitgliedschaftsanfrage für den Kreis \"%2$s\" gesendet",
    "Leave the circle" : "Diesen Kreis verlassen"
},
"nplurals=2; plural=(n != 1);");
